from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import String, File, Int, Float, Array

Hicdetectloops_V0_1_0 = CommandToolBuilder(tool="hicDetectLoops", base_command=["hicDetectLoops"], inputs=[ToolInput(tag="in_matrix", input_type=String(optional=True), prefix="--matrix", doc=InputDocumentation(doc="The matrix to compute the loop detection on.")), ToolInput(tag="in_out_filename", input_type=File(optional=True), prefix="--outFileName", doc=InputDocumentation(doc="Outfile name to store the detected loops. The file\nwill in bedgraph format.")), ToolInput(tag="in_peak_width", input_type=Int(optional=True), prefix="--peakWidth", doc=InputDocumentation(doc="The width of the peak region in bins. The square\naround the peak will include (2 * peakWidth)^2 bins\n(Default: 2).")), ToolInput(tag="in_window_size", input_type=Int(optional=True), prefix="--windowSize", doc=InputDocumentation(doc="The window size for the neighborhood region the peak\nis located in. All values from this region (exclude\nthe values from the peak region) are tested against\nthe peak region for significant difference. The square\nwill have the size of (2 * windowSize)^2 bins\n(Default: 5).")), ToolInput(tag="in_p_value_preselection", input_type=File(optional=True), prefix="--pValuePreselection", doc=InputDocumentation(doc="Only candidates with p-values less the given threshold\nwill be considered as candidates. For each genomic\ndistance a negative binomial distribution is fitted\nand for each pixel a p-value given by the cumulative\ndensity function is given. This does NOT influence the\np-value for the neighborhood testing. Can a single\nvalue or a threshold file created by\nhicCreateThresholdFile (Default: 0.1).")), ToolInput(tag="in_peak_interactions_threshold", input_type=Int(optional=True), prefix="--peakInteractionsThreshold", doc=InputDocumentation(doc="The minimum number of interactions a detected peaks\nneeds to have to be considered (Default: 10).")), ToolInput(tag="in_obs_exp_threshold", input_type=Int(optional=True), prefix="--obsExpThreshold", doc=InputDocumentation(doc="The minimum number of obs/exp interactions a detected\npeaks needs to have to be considered (Default: 1.5).")), ToolInput(tag="in_p_value", input_type=Float(optional=True), prefix="--pValue", doc=InputDocumentation(doc="Rejection level for Anderson-Darling or Wilcoxon-rank\nsum test for H0. H0 is peak region and background have\nthe same distribution (Default: 0.025).")), ToolInput(tag="in_max_loop_distance", input_type=Int(optional=True), prefix="--maxLoopDistance", doc=InputDocumentation(doc="Maximum genomic distance of a loop, usually loops are\nwithin a distance of ~2MB (Default: 2000000).")), ToolInput(tag="in_chromosomes", input_type=Array(t=String(), optional=True), prefix="--chromosomes", doc=InputDocumentation(doc="Chromosomes to include in the analysis. If not set,\nall chromosomes are included.")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="--threads", doc=InputDocumentation(doc="Number of threads to use, the parallelization is\nimplemented per chromosome (Default: 4).")), ToolInput(tag="in_threads_per_chromosome", input_type=Int(optional=True), prefix="--threadsPerChromosome", doc=InputDocumentation(doc="Number of threads to use per parallel thread\nprocessing a chromosome. E.g. --threads = 4 and\n--threadsPerChromosome = 4 makes 4 * 4 = 16 threads in\ntotal (Default: 4).")), ToolInput(tag="in_expected", input_type=String(optional=True), prefix="--expected", doc=InputDocumentation(doc="Method to compute the expected value per distance:\nEither the mean (mean), the mean of non-zero values\n(mean_nonzero) or the mean of non-zero values with\nligation factor correction (mean_nonzero_ligation)\n(Default: mean)."))], outputs=[ToolOutput(tag="out_out_filename", output_type=File(optional=True), selector=InputSelector(input_to_select="in_out_filename", type_hint=File()), doc=OutputDocumentation(doc="Outfile name to store the detected loops. The file\nwill in bedgraph format."))], container="quay.io/biocontainers/hicexplorer:3.6--py_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Hicdetectloops_V0_1_0().translate("wdl")

